@@ -1,6 +1,8 @@
 package Mojo::Reactor::Epoll;
 use Mojo::Base 'Mojo::Reactor';
 
+$ENV{MOJO_REACTOR} ||= 'Mojo::Reactor::Epoll';
+
 use IO::Epoll qw(EPOLLERR EPOLLHUP EPOLLIN EPOLLOUT EPOLLPRI
 	EPOLL_CTL_ADD EPOLL_CTL_MOD EPOLL_CTL_DEL
 	epoll_create epoll_ctl epoll_wait);
@@ -11,7 +13,7 @@ use Time::HiRes 'usleep';
 
 use constant DEBUG => $ENV{MOJO_REACTOR_EPOLL_DEBUG} || 0;
 
-our $VERSION = '0.001';
+our $VERSION = '0.002';
 
 sub DESTROY {
 	my $epfd = delete shift->{epfd};
@@ -231,17 +233,22 @@ Mojo::Reactor::Epoll - epoll backend for Mojo::Reactor
   $reactor->start unless $reactor->is_running;
 
   # Or in an application using Mojo::IOLoop
-  BEGIN { $ENV{MOJO_REACTOR} = 'Mojo::Reactor::Epoll' }
+  use Mojo::Reactor::Epoll;
   use Mojo::IOLoop;
+  
+  # Or in a Mojolicious application
+  $ MOJO_REACTOR=Mojo::Reactor::Epoll hypnotoad script/myapp
 
 =head1 DESCRIPTION
 
 L<Mojo::Reactor::Epoll> is an event reactor for L<Mojo::IOLoop> that uses the
 C<epoll(7)> Linux subsystem. The usage is exactly the same as other
-L<Mojo::Reactor> implementations such as L<Mojo::Reactor::Poll>. To set it as
-the default backend for L<Mojo::IOLoop>, set the C<MOJO_REACTOR> environment
-variable to C<Mojo::Reactor::Epoll>. This must be set before L<Mojo::IOLoop> is
-loaded.
+L<Mojo::Reactor> implementations such as L<Mojo::Reactor::Poll>.
+L<Mojo::Reactor::Epoll> will be used as the default backend for L<Mojo::IOLoop>
+if it is loaded before L<Mojo::IOLoop> or any module using the loop. However,
+when invoking a L<Mojolicious> application through L<morbo> or L<hypnotoad>,
+the reactor must be set as the default by setting the C<MOJO_REACTOR>
+environment variable to C<Mojo::Reactor::Epoll>.
 
 =head1 EVENTS
 
